@@ -2,7 +2,7 @@ package Hook::Output::Tiny;
 use strict;
 use warnings;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 use Carp qw(croak);
 
@@ -149,9 +149,8 @@ __END__
 Hook::Output::Tiny - Easily enable/disable trapping of STDOUT/STDERR
 
 =for html
-<a href="https://github.com/stevieb/=/actions"><img src="https://github.com/stevieb/=/workflows/CI/badge.svg"/></a>
-<a href="https://ci.appveyor.com/project/stevieb9/p5-hook-output-tiny"><img src="https://ci.appveyor.com/api/projects/status/br01o72b3if3plsw/branch/master?svg=true"/></a>
-<a href='https://coveralls.io/github/stevieb/=?branch=master'><img src='https://coveralls.io/repos/stevieb/=/badge.svg?branch=master&service=github' alt='Coverage Status' /></a>
+<a href="https://github.com/stevieb9/p5-hook-output-tiny/actions"><img src="https://github.com/stevieb9/p5-hook-output-tiny/workflows/CI/badge.svg"/></a>
+<a href='https://coveralls.io/github/stevieb9/=?branch=master'><img src='https://coveralls.io/repos/stevieb9/p5-hook-output-tiny/badge.svg?branch=master&service=github' alt='Coverage Status' /></a>
 
 =head1 SYNOPSIS
 
